GoogleSearchTenorV2RegisterShareRequest

Struct GoogleSearchTenorV2RegisterShareRequest 

pub struct GoogleSearchTenorV2RegisterShareRequest {
Show 13 fields pub anon_id: Option<String>, pub apirefid: Option<String>, pub appversion: Option<String>, pub client_key: Option<String>, pub component: Option<String>, pub country: Option<String>, pub id: Option<u64>, pub index: Option<i64>, pub locale: Option<String>, pub multi: Option<i64>, pub q: Option<String>, pub result_token: Option<String>, pub searchfilter: Option<String>,
}
There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

anon_id: Option<String>

Pseudonymous user id tied to a client installation on a user’s device.

apirefid: Option<String>

Used as a session/journey identifier for client events.

appversion: Option<String>

Client application version, e.g., “3.1”.

client_key: Option<String>

Client application identifier, e.g., “gboard”.

component: Option<String>

Client-specific. UI component where the share was initiated.

country: Option<String>

User’s location in ISO 3166-1 alpha-2 code, e.g., “CA”, “GB”.

id: Option<u64>

Post id (pid) of the GIF_OBJECT shared.

index: Option<i64>

Position of the shared post in the search results list, starting at 0 for the first result. If the share did not result from the user clicking on a result returned by the v2/search endpoint, this value should be -1 to indicate that there is no meaningful index.

locale: Option<String>

User’s preferred locale as BCP 47 language tag, e.g. “en”, “en-US”. Note that this is not dependent on the user’s current location.

multi: Option<i64>

Number of people this post was shared to.

q: Option<String>

The query that led to this share, if any.

result_token: Option<String>

Result token pulled from the result in the SearchPostsResponse.

searchfilter: Option<String>

Search filter string used in the search query that led to the share. An empty search filter string will default to ‘-static,-sticker’ and the string ‘none’ will apply no search filter.